@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Empty Folders Plugin
-  * Copyright (c) 2003-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2008 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -43,7 +43,7 @@ empty_folders_init();
 
 
 global $username, $data_dir;
-$location = get_location();
+$base_uri = sqm_baseuri();
 
 
 
@@ -60,7 +60,7 @@ if (!empty($mailbox))
 else
 {
    session_write_close();
-   header('Location: ' . $location . '/../../src/left_main.php');
+   header('Location: ' . $base_uri . 'src/left_main.php');
    exit;
 }
    
@@ -79,7 +79,7 @@ if (sqGetGlobalVar('ef_act', $ef_action, SQ_FORM) && !empty($ef_action))
 if (is_null($moveToTrash))
 {
    session_write_close();
-   header('Location: ' . $location . '/../../src/left_main.php');
+   header('Location: ' . $base_uri . 'src/left_main.php');
    exit;
 }
 
@@ -113,7 +113,7 @@ if (check_sm_version(1, 5, 2))
 
 
 session_write_close();
-header('Location: ' . $location . '/../../src/left_main.php');
+header('Location: ' . $base_uri . 'src/left_main.php');
 exit;
 
 
