@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Empty Folders Plugin
-  * Copyright (c) 2003-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2008 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -1067,10 +1067,10 @@ function empty_folders_rpc_do($args)
             $mailbox_cache[$account_number . '_' . $mbox_cache['NAME']] = $mbox_cache;
             sqsession_register($mailbox_cache, 'mailbox_cache');
 
-            sm_rpc_return_success($args[0], 0, $success_message);
+            sm_rpc_return_success(0, $success_message);
          }
          else
-            sm_rpc_return_error($args[0], 500, $error_message, 'server', 500, 'Server Error');
+            sm_rpc_return_error(500, $error_message);
          break;
 
 
@@ -1100,10 +1100,10 @@ function empty_folders_rpc_do($args)
             $mailbox_cache[$account_number . '_' . $mbox_cache['NAME']] = $mbox_cache;
             sqsession_register($mailbox_cache, 'mailbox_cache');
 
-            sm_rpc_return_success($args[0], 0, $success_message);
+            sm_rpc_return_success(0, $success_message);
          }
          else
-            sm_rpc_return_error($args[0], 501, $error_message, 'server', 500, 'Server Error');
+            sm_rpc_return_error(501, $error_message);
          break;
 
 
@@ -1133,10 +1133,10 @@ function empty_folders_rpc_do($args)
             $mailbox_cache[$account_number . '_' . $mbox_cache['NAME']] = $mbox_cache;
             sqsession_register($mailbox_cache, 'mailbox_cache');
 
-            sm_rpc_return_success($args[0], 0, $success_message);
+            sm_rpc_return_success(0, $success_message);
          }
          else
-            sm_rpc_return_error($args[0], 502, $error_message, 'server', 500, 'Server Error');
+            sm_rpc_return_error(502, $error_message);
          break;
 
    }
